==> zio-aws-chimesdkmeetings_2.13-5.17.116.2-sources.jar: zio/aws/chimesdkmeetings/model/package.scala <==
package zio.aws.chimesdkmeetings
import zio.prelude.Subtype
import zio.aws.chimesdkmeetings.model.primitives.ResultMax.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.chimesdkmeetings.model.primitives.Arn.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.chimesdkmeetings.model.primitives.ClientRequestToken.Type
    object ExternalMeetingId extends Subtype[String]
    type ExternalMeetingId =
      zio.aws.chimesdkmeetings.model.primitives.ExternalMeetingId.Type
    object ExternalUserId extends Subtype[String]
    type ExternalUserId =
      zio.aws.chimesdkmeetings.model.primitives.ExternalUserId.Type
    object GuidString extends Subtype[String]
    type GuidString = zio.aws.chimesdkmeetings.model.primitives.GuidString.Type
    object JoinTokenString extends Subtype[String]
    type JoinTokenString =
      zio.aws.chimesdkmeetings.model.primitives.JoinTokenString.Type
    object MediaRegion extends Subtype[String]
    type MediaRegion =
      zio.aws.chimesdkmeetings.model.primitives.MediaRegion.Type
    object ResultMax extends Subtype[Int]
    type ResultMax = zio.aws.chimesdkmeetings.model.primitives.ResultMax.Type
    object TranscribeLanguageModelName extends Subtype[String]
    type TranscribeLanguageModelName =
      zio.aws.chimesdkmeetings.model.primitives.TranscribeLanguageModelName.Type
    object TranscribePiiEntityTypes extends Subtype[String]
    type TranscribePiiEntityTypes =
      zio.aws.chimesdkmeetings.model.primitives.TranscribePiiEntityTypes.Type
  }
  type AttendeeList = List[zio.aws.chimesdkmeetings.model.Attendee]
  type BatchCreateAttendeeErrorList =
    List[zio.aws.chimesdkmeetings.model.CreateAttendeeError]
  type CreateAttendeeRequestItemList =
    List[zio.aws.chimesdkmeetings.model.CreateAttendeeRequestItem]
  type CreateMeetingWithAttendeesRequestItemList =
    List[zio.aws.chimesdkmeetings.model.CreateAttendeeRequestItem]
}

==> zio-aws-chimesdkmeetings_2.13-5.17.145.1-sources.jar: zio/aws/chimesdkmeetings/model/package.scala <==
package zio.aws.chimesdkmeetings
import zio.prelude.Subtype
import zio.aws.chimesdkmeetings.model.primitives.ResultMax.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.chimesdkmeetings.model.primitives.Arn.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.chimesdkmeetings.model.primitives.ClientRequestToken.Type
    object ExternalMeetingId extends Subtype[String]
    type ExternalMeetingId =
      zio.aws.chimesdkmeetings.model.primitives.ExternalMeetingId.Type
    object ExternalUserId extends Subtype[String]
    type ExternalUserId =
      zio.aws.chimesdkmeetings.model.primitives.ExternalUserId.Type
    object GuidString extends Subtype[String]
    type GuidString = zio.aws.chimesdkmeetings.model.primitives.GuidString.Type
    object JoinTokenString extends Subtype[String]
    type JoinTokenString =
      zio.aws.chimesdkmeetings.model.primitives.JoinTokenString.Type
    object MediaRegion extends Subtype[String]
    type MediaRegion =
      zio.aws.chimesdkmeetings.model.primitives.MediaRegion.Type
    object ResultMax extends Subtype[Int]
    type ResultMax = zio.aws.chimesdkmeetings.model.primitives.ResultMax.Type
    object TranscribeLanguageModelName extends Subtype[String]
    type TranscribeLanguageModelName =
      zio.aws.chimesdkmeetings.model.primitives.TranscribeLanguageModelName.Type
    object TranscribeLanguageOptions extends Subtype[String]
    type TranscribeLanguageOptions =
      zio.aws.chimesdkmeetings.model.primitives.TranscribeLanguageOptions.Type
    object TranscribePiiEntityTypes extends Subtype[String]
    type TranscribePiiEntityTypes =
      zio.aws.chimesdkmeetings.model.primitives.TranscribePiiEntityTypes.Type
  }
  type AttendeeList = List[zio.aws.chimesdkmeetings.model.Attendee]
  type BatchCreateAttendeeErrorList =
    List[zio.aws.chimesdkmeetings.model.CreateAttendeeError]
  type CreateAttendeeRequestItemList =
    List[zio.aws.chimesdkmeetings.model.CreateAttendeeRequestItem]
  type CreateMeetingWithAttendeesRequestItemList =
    List[zio.aws.chimesdkmeetings.model.CreateAttendeeRequestItem]
}
